\name{hcl}
\alias{hcl}
\title{Create R Colours from Hue, Chroma and Luminance}
\description{
  This function creates a vector of R colours with the
  the given hue, chroma and luminance values.
}
\usage{
hcl(h = 0, c = 35, l = 85, gamma = 2.2, fixup = TRUE)
}
\arguments{
  \item{h}{The hue of the color as an angle in the interval [0,360].}
  \item{c}{The chroma of the color.}
  \item{l}{The luminance of the colour}
  \item{gamma}{The gamma value for the device the colours are to
    be viewed on.}
  \item{fixup}{a logical value which indicates whether a ``close''
    color should be substituted when the specified colour is out
    of gammut.}
}
\details{
  This function is intended as an alternative to color specification
  with the R \code{hsv} function.  The use of this function is more
  firmly based in perceptual theory.
}
\value{
  A vector (of character strings) wich can be used as color
  specifications for other R functions.
}
\references{Ihaka, R. (2003).
  ``Colour for Presentation Graphics,''
  Proceedings of DSC-2003.
}
\author{Ross Ihaka}
\examples{
barplot(rep(1, 12), col = hcl(seq(0, 360, length = 13)[1:12]))
}
\keyword{color}
\eof
\name{hex2RGB}
\alias{hex2RGB}
\title{Convert Hexadecimal Color Specifications To RGB Objects}
\description{
  This function takes a vector of strings of the form
  \code{"#RRGGBB"} (hexdecimal color descriptions) into
  RGB objects.
}
\usage{
hex2RGB(x, gamma = 2.2)
}
\arguments{
  \item{x}{a vector of hexdecimal color descriptions.}
  \item{gamma}{the display gamma value.  Passing a value
    of \code{NA} results in no gamma correction being
    applied.}
}
\details{
  This function converts device dependent color descriptions of the
  form \code{"#RRGGBB"} into device independent sRGB colour descriptions.
}
\value{
  An RGB object describing the colours.
}
%\references{ ~put references to the literature/web site here ~ }
\author{Ross Ihaka}
%\note{ ~~further notes~~ }
\seealso{
  \code{\link{hex}},
  \code{\link{RGB}},
  \code{\link{HSV}},
  \code{\link{XYZ}},
  \code{\link{polarLAB}},
  \code{\link{LUV}},
  \code{\link{polarLUV}}.
}

\examples{
rgb = hex2RGB("#FF0000","#00FF00", "#0000FF")
}
\keyword{color}
\eof
\name{hex}
\alias{hex}
\title{Convert Colors To Hexadecimal Strings}
\description{
  This functions converts ``color'' objects into
  hexadecimal strings.
}
\usage{
hex(from, gamma = 2.4, fixup = FALSE)
}
\arguments{
  \item{from}{The color object to be converted.}
  \item{gamma}{The display \italic{gamma} value.}
  \item{fixup}{Should the color be corrected to a valid
    RGB value before correction.  The default is to convert
    out-of-gamut colors to the string \code{"NA"}.}
}
\details{
  The color objects are first converted to RGB color objects.
  They are then multiplied by 255 and rounded to obtain an
  integer value.  These values are then converted to hexadecimal
  strings of the form \code{"#RRGGBB"} and suitable for use
  as color descriptions for R graphics.  Out of gamut values
  are either corrected to valid RGB values by translating the
  the individual primary values so that they lie between 0 and 255.
}
\value{
  A vector of character strings.
}
%\references{ ~put references to the literature/web site here ~ }
\author{Ross Ihaka}
%\note{ ~~further notes~~ }
\seealso{
  \code{\link{hex2RGB}},
  \code{\link{RGB}},
  \code{\link{HSV}},
  \code{\link{XYZ}},
  \code{\link{LAB}},
  \code{\link{polarLAB}},
  \code{\link{LUV}},
  \code{\link{polarLUV}}.
}

\examples{
hsv = HSV(seq(0,360,length=7)[-7], 1, 1)
barplot(rep(1,6), col=hex(hsv))
}

\keyword{color}
\eof
\name{HSV}
\alias{HSV}
\title{Create HSV Colors}
\description{
  This function creates colors of class HSV;
  a subclass of the virtual ``color'' class.
}
\usage{
HSV(H, S, V,names = NULL)
}
\arguments{
  \item{H,S,V}{These arguments give the hue, saturation and value
    of the colors. The values can be provided in separate \code{H},
    \code{S} and \code{V} vectors or in a three-column matrix passed
    as \code{H}.
  }
  \item{names}{A vector of names for the colors.}
}
\details{
  This function creates colors in the HSV color space which corresponds
  to the standard sRGB color space (IEC standard 61966).
  The hues should lie between between 0 and 360, and the saturations and
  values should lie between 0 and 1.
}
\value{
  An object of class ``HSV'' which inherits from class ``color.''
}
\references{\url{www.srgb.com}}
\author{Ross Ihaka}
%\note{ ~~further notes~~ }

\seealso{
  \code{\link{RGB}},
  \code{\link{XYZ}},
  \code{\link{LAB}},
  \code{\link{polarLAB}},
  \code{\link{LUV}},
  \code{\link{polarLUV}}.
}

\examples{
# A rainbow of full-intensity hues
hsv = HSV(seq(0, 360, length=13)[-13], 1, 1)
}

\keyword{color}
\eof
\name{LAB}
\alias{LAB}
\title{Create LAB Colors}
\description{
  This function creates colors of class ``LAB'';
  a subclass of the virtual ``color'' class.
}
\usage{
LAB(L, A, B, names = NULL)
}
\arguments{
  \item{L,A,B}{these arguments give the L, A and B coordinates of
    the colors.  The values can be provided in separate \code{L},
    \code{A} and \code{B} vectors or in a three-column matrix
    passed as \code{L}.}
  \item{names}{a vector of names for the colors.}
}
\details{
  The \code{L}, \code{A} and \code{B} values give the coordinates of
  the colors in the CIE \eqn{L^*a^*b^*}{L*a*b*} space.
  This is a transformation of the 1931 CIE XYZ space which attempts to
  produce perceptually based axes.
  Luminance takes values between 0 and 100, and the other coordinates
  take values between -100 and 100.  The \eqn{a} and \eqn{b} coordinates
  measure positions on green/red and blue/yellow axes.
}
\value{
  An object of class ``LAB'' which inherits from class ``color.''
}
%\references{ ~put references to the literature/web site here ~ }
\author{Ross Ihaka}
%\note{ ~~further notes~~ }

\seealso{
  \code{\link{RGB}},
  \code{\link{HSV}},
  \code{\link{XYZ}},
  \code{\link{LAB}},
  \code{\link{polarLAB}},
  \code{\link{LUV}},
  \code{\link{polarLUV}}.
}

\examples{
## Show the LAB space
x = RGB(runif(1000), runif(1000), runif(1000))
plot(as(x,"LAB"))
}
\keyword{color}
\eof
\name{LUV}
\alias{LUV}
\title{Create LUV Colors}
\description{
  This function creates colors of class ``LUV'';
  a subclass of the virtual ``color'' class.
}
\usage{
LUV(L, U, V, names = NULL)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{L,U,V}{these arguments give the L, U and V coordinates of
    the colors.  The values can be provided in separate \code{L},
    \code{U} and \code{V} vectors or in a three-column matrix
    passed as \code{L}.}
  \item{names}{a vector of names for the colors.}
}
\details{
  The \code{L}, \code{U} and \code{V} values give the coordinates of
  the colors in the CIE (1976) \eqn{L^*u^*v^*}{L*u*v*} space.
  This is a transformation of the 1931 CIE XYZ space which attempts to
  produce perceptually based axes.
  Luminance takes values between 0 and 100, and the other coordinates
  take values between -100 and 100.  The \eqn{a} and \eqn{b} coordinates
  measure positions on green/red and blue/yellow axes.
}
\value{
  An object of class ``LUV'' which inherits from class ``color.''
}
%\references{ ~put references to the literature/web site here ~ }
\author{Ross Ihaka}
%\note{ ~~further notes~~ }

\seealso{
  \code{\link{RGB}},
  \code{\link{HSV}},
  \code{\link{XYZ}},
  \code{\link{LAB}},
  \code{\link{polarLAB}},
  \code{\link{polarLUV}}.
}

\examples{
## Show the LUV space
x = RGB(runif(1000), runif(1000), runif(1000))
plot(as(x,"LUV"))
}
\keyword{color}
\eof
\name{polarLAB}
\alias{polarLAB}
\title{Create polarLAB Colors}
\description{
 This function creates colors of class ``polarLAB'';
  a subclass of the virtual ``color'' class.
}
\usage{
polarLAB(L, C, H, names = NULL)
}
\arguments{
  \item{L,C,H}{these arguments give the L, C and H coordinates of
    the colors.  The values can be provided in separate \code{L},
    \code{C} and \code{H} vectors or in a three-column matrix
    passed as \code{L}.}
  \item{names}{}
}
\details{
  The polarLAB space is a transformation of the CIE \eqn{L^*a^*b^*}{L*a*b*}
  space so that the \eqn{a} and \eqn{b} values are converted to polar
  coordinates.  The radial component \eqn{C} measures chroma and
  the angular coordinate \eqn{H} is measures hue.
}
\value{
  An object of class ``polarLAB'' which inherits from class ``color.''
}
%\references{ ~put references to the literature/web site here ~ }
\author{Ross Ihaka}
%\note{ ~~further notes~~ }

\seealso{
  \code{\link{RGB}},
  \code{\link{HSV}},
  \code{\link{XYZ}},
  \code{\link{LAB}},
  \code{\link{polarLAB}},
  \code{\link{LUV}},
  \code{\link{polarLUV}}.
}

\examples{
## Show the polarLAB space
x = RGB(runif(1000), runif(1000), runif(1000))
plot(as(x,"polarLAB"))
}
\keyword{color}
\eof
\name{polarLUV}
\alias{polarLUV}
\title{Create polarLUV Colors}
\description{
 This function creates colors of class ``polarLUV'';
  a subclass of the virtual ``color'' class.
}
\usage{
polarLUV(L, C, H, names = NULL)
}
\arguments{
  \item{L,C,H}{these arguments give the L, C and H coordinates of
    the colors.  The values can be provided in separate \code{L},
    \code{C} and \code{H} vectors or in a three-column matrix
    passed as \code{L}.}
  \item{names}{}
}
\details{
  The polarLUV space is a transformation of the CIE \eqn{L^*u^*u^*}{L*u*u*}
  space so that the \eqn{u} and \eqn{u} values are converted to polar
  coordinates.  The radial component \eqn{C} measures chroma and
  the angular coordinate \eqn{H} is measures hue.
}
\value{
  An object of class ``polarLUV'' which inherits from class ``color.''
}
%\references{ ~put references to the literature/web site here ~ }
\author{Ross Ihaka}
%\note{ ~~further notes~~ }

\seealso{
  \code{\link{RGB}},
  \code{\link{HSV}},
  \code{\link{XYZ}},
  \code{\link{LAB}},
  \code{\link{polarLAB}},
  \code{\link{LUV}},
  \code{\link{polarLUV}}.
}

\examples{
## Show the polarLUV space
x = RGB(runif(1000), runif(1000), runif(1000))
plot(as(x,"polarLUV"))
}
\keyword{color}
\eof
\name{readhex}
\alias{readhex}
\title{Read Hexadecimal Color Descriptions}
\description{
  This function reads a set of hexadecimal color
  descriptions from a file and creates a color
  object containing the corresponding colors.
}
\usage{
readhex(file = "", class = "RGB")
}
\arguments{
  \item{file}{The file containing the color descriptions.}
  \item{class}{The kind of color object to be returned.}
}
\details{
  The file is assumed to contain hexadecimal color descriptions
  of the form \code{#RRGGBB}.
}
\value{
  An color object of the specified class containing the color
  descriptions.
}
%\references{ ~put references to the literature/web site here ~ }
\author{Ross Ihaka.}
%\note{ ~~further notes~~ }
\seealso{
  \code{\link{writehex}},
  \code{\link{readRGB}},
  \code{\link{hex2RGB}},
  \code{\link{RGB}},
  \code{\link{HSV}},
  \code{\link{XYZ}},
  \code{\link{LAB}},
  \code{\link{polarLAB}},
  \code{\link{LUV}},
  \code{\link{polarLUV}},
}
\examples{
rgb = readhex("pastel.txt")
hsv = readhex("pastel.txt", "HSV")
}
\keyword{color}
\eof
\name{readRGB}
\alias{readRGB}
\title{Read RGB Color Descriptions}
\description{
  This function reads a set of RGB color descriptions (of the form
  written by \code{gcolorsel}) from a file and creates a color
  object containing the corresponding colors.
  
}
\usage{
readRGB(file = "", class = "RGB")
}
\arguments{
  \item{file}{The file containing the color descriptions.}
  \item{class}{The kind of color object to be returned.}
}
\details{
  The file is assumed to contain RGB color descriptions
  consisting of three integer values in the range from
  0 to 255 followed by a color name.
}
\value{
  An color object of the specified class containing the color
  descriptions.
}
%\references{ ~put references to the literature/web site here ~ }
\author{Ross Ihaka.}
%\note{ ~~further notes~~ }
\seealso{
  \code{\link{writehex}},
  \code{\link{readhex}},
  \code{\link{hex2RGB}},
  \code{\link{RGB}},
  \code{\link{HSV}},
  \code{\link{XYZ}},
  \code{\link{LAB}},
  \code{\link{polarLAB}},
  \code{\link{LUV}},
  \code{\link{polarLUV}}.
}
\examples{
rgb = readRGB("pastel.rgb")
hsv = readRGB("pastel.rgb", "HSV")
}
\keyword{color}
\eof
\name{RGB}
\alias{RGB}
\title{Create RGB Colors}
\description{
  This function creates colors of class RGB;
  a subclass of the virtual ``color'' class.
}
\usage{
RGB(R, G, B, names = NULL)
}
\arguments{
  \item{R,G,B}{these arguments give the red, green and blue
    intensities of the colors (the values should lie between 0 and 1).
    The values can be provided in separate \code{R}, \code{G} and
    \code{B} vectors or in a three-column matrix passed as \code{R}.
  } 
  \item{names}{The (optional) names to be given to the colors.}
}
\details{
  This function creates colors in the standard sRGB
  color space (IEC standard 61966).
}
\value{
  An object of class ``RGB'' which inherits from class ``color.''
}
\references{\url{www.srgb.com}}
\author{Ross Ihaka}
%\note{ ~~further notes~~ }

\seealso{
  \code{\link{HSV}},
  \code{\link{XYZ}},
  \code{\link{LAB}},
  \code{\link{polarLAB}},
  \code{\link{LUV}},
  \code{\link{polarLUV}}.
}

\examples{
# Create a random set of colors
rgb = RGB(R = runif(20), G = runif(20), B = runif(20))
}
\keyword{color}
\eof
\name{writehex}
\alias{writehex}
\title{Write Hexadecimal Color Descriptions}
\description{
  Given a color object, this function writes a file
  containing the hexadecimal representation of the
  colors in the object.
}
\usage{
writehex(x, file = "")
}
\arguments{
  \item{x}{a color object.}
  \item{file}{the name of the file to be written.}
}
\details{
  This function converts the given color oject to RGB and
  then writes hexadecimal strings (of the form \code{#RRGGBB})
  representing the colors to the specified file.  
}
\value{
  The name of the file is returned as the value of the function.
}
%\references{ ~put references to the literature/web site here ~ }
\author{Ross Ihaka}
%\note{ ~~further notes~~ }
\seealso{
  \code{\link{readhex}},
  \code{\link{readRGB}},
  \code{\link{hex2RGB}},
  \code{\link{RGB}},
  \code{\link{HSV}},
  \code{\link{XYZ}},
  \code{\link{LAB}},
  \code{\link{polarLAB}},
  \code{\link{LUV}},
  \code{\link{polarLUV}}.
}

\examples{
x = RGB(runif(10), runif(10), runif(10))
writehex(x, "random.txt")
}
\keyword{color}
\eof
\name{XYZ}
\alias{XYZ}
\title{Create XYZ Colors}
\description{
 This function creates colors of class XYZ;
  a subclass of the virtual ``color'' class.
}
\usage{
XYZ(X, Y, Z, names = NULL)
}
\arguments{
  \item{X,Y,Z}{these arguments give the X, Y and Z coordinates of
    the colors.  The values can be provided in separate \code{X},
    \code{Y} and \code{Z} vectors or in a three-column matrix
    passed as \code{X}.}
  \item{names}{A vector of names for the colors.}
}
\details{
  The X, Y and Z values are the levels of the CIE primaries.
  These are scaled so that the luminance of the display white-point
  is 100.  The white-point is taken to be D65, which means
  that its coordinates are  95.047, 100.000, 108.883.
}
\value{
  An object of class ``XYZ'' which inherits from class ``color.''
}
%\references{\url{}}
\author{Ross Ihaka}
%\note{ ~~further notes~~ }
\seealso{
  \code{\link{RGB}},
  \code{\link{HSV}},
  \code{\link{LAB}},
  \code{\link{polarLAB}},
  \code{\link{LUV}},
  \code{\link{polarLUV}}.
}

\examples{
## Generate white in XYZ space
white = XYZ(95.047, 100.000, 108.883)
}
\keyword{color}
\eof
